0.2.25 (2023-12-10)
-------------------

Use the original image if no renditions are generated. Includes now a
management command to sync renditions. Revisited how the renditions are
passed to the template.

- #112 If no renditions are generated, use the original image as the default rendition
- #113 Management command to sync renditions
- Changed tox.ini to include Django 5.0 and removed Django 4.0
